@@ -4,11 +4,13 @@ use warnings;
 
 sub foo {}
 
+1;
+
 __END__
 
 =head1 NAME
 
-Stopword::Pod - correctly spelled POD and a xzaue creator
+Stopword::Pod - correctly spelled POD and a Xzaue creator
 
 =END
 
